@@ -1,28 +1,26 @@
-from functools import partial
-
 import numpy as np
 
-import jax.numpy as jnp
-
-from jax import jit
-
 from jax import vmap
 
+import jax.numpy as jnp
+
 
 class Constraint:
     """
     Base class for all constraints.
     """
-    def __init__(self, key, bound_low, bound_up):
+    def __init__(self, key, bound_low=None, bound_up=None):
         self._key = None
-        self._bound_low = None
-        self._bound_up = None
-        self._index = None
-
         self.key = key
+
+        self._bound_low = None
         self.bound_low = bound_low
+
+        self._bound_up = None
         self.bound_up = bound_up
 
+        self._index = None
+
     @property
     def key(self):
         """
@@ -47,6 +45,18 @@ class Constraint:
             index = [index]
         self._index = np.array(index)
 
+    @staticmethod
+    def _bound_setter(bound):
+        """
+        Set a bound.
+        """
+        if not isinstance(bound, (int, float)):
+            if len(bound) == 1:
+                bound = bound[0]
+            else:
+                bound = np.ravel(bound)
+        return bound
+
     @property
     def bound_low(self):
         """
@@ -56,12 +66,9 @@ class Constraint:
 
     @bound_low.setter
     def bound_low(self, bound):
-        if not isinstance(bound, (int, float)):
-            if len(bound) == 1:
-                bound = bound[0]
-            else:
-                bound = np.ravel(bound)
-        self._bound_low = bound
+        if bound is None:
+            bound = -jnp.inf
+        self._bound_low = self._bound_setter(bound)
 
     @property
     def bound_up(self):
@@ -72,12 +79,16 @@ class Constraint:
 
     @bound_up.setter
     def bound_up(self, bound):
-        if not isinstance(bound, (int, float)):
-            if len(bound) == 1:
-                bound = bound[0]
-            else:
-                bound = np.ravel(bound)
-        self._bound_up = bound
+        if bound is None:
+            bound = jnp.inf
+        self._bound_up = self._bound_setter(bound)
+
+    @staticmethod
+    def index_from_model(model):
+        """
+        Get the index in the model of the constraint key.
+        """
+        raise NotImplementedError
 
     def init(self, model):
         """
@@ -85,20 +96,15 @@ class Constraint:
         """
         self.index = self.index_from_model(model)
 
-    # def __call__(self, q, model):
-    #     """
-    #     The constraint function.
-    #     """
-    #     eqstate = model(q)
-    #     return self.constraint(eqstate, model)
-
-    @partial(jit, static_argnums=(0, 4))
     def __call__(self, q, xyz_fixed, loads, model):
         """
         The called constraint function.
         """
         eqstate = model(q, xyz_fixed, loads)
         constraint = vmap(self.constraint, in_axes=(None, 0))(eqstate, self.index)
+
+        # assert jnp.ravel(constraint).shape == jnp.ravel(self.index).shape, f"Constraint shape: {constraint.shape} vs. index shape: {self.index.shape}"
+
         return jnp.ravel(constraint)
 
     def constraint(self, eqstate, index):
