@@ -1,6 +1,6 @@
 from .errors import *  # noqa F403
 from .regularizers import *  # noqa F403
-from .losses import *  # noqa F403
+from .loss import *  # noqa F403
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
