@@ -1,4 +1,4 @@
-from .network import *  # noqa F403
+from .network_artist import *  # noqa F403
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
